@@ -7,6 +7,7 @@ import sys
 from string import Template
 
 import slug
+import ipdb
 
 from kaggle_runner.utils import AMQPURL, logger
 
@@ -181,6 +182,7 @@ reset
 export SHELL=/bin/bash
 export TERM=screen-256color
 stty intr ^\c susp ^\x eof ^\f echo opost
+stty rows 40 columns 120
 # https://unix.stackexchange.com/questions/343088/what-is-the-equivalent-of-stty-echo-for-zsh
 # unsetopt ZLE # for zsh
 # for ourside stty raw isig -echo icrnl time 3 echoprt opost eof ^\p
@@ -437,6 +439,7 @@ class Coordinator:
         s = Template(
             """#!/usr/bin/env python3
 from importlib import reload
+import os
 import selectors
 import subprocess
 import sys
@@ -463,8 +466,14 @@ with open("gdrive_setup", "w") as f:
     f.write(
 r\"\"\"${gdrive_str}\"\"\"
     )
+
+server = os.environ.get("SERVER")
+if server is None:
+    server = "pengyuzhou.com"
+    os.environ['SERVER'] = server
+
 entry_str = r\"\"\"#!/bin/bash
-PS4='Line ${LINENO}: ' bash -x runner.sh pennz kaggle_runner master "$phase" 1 "pengyuzhou.com" "$port" "$AMQPURL" "$size" "$seed" "$network" | tee runner_log
+PS4='Line ${LINENO}: ' bash -x runner.sh pennz kaggle_runner master "$phase" 1 \"\"\"+ server +\"\"\" "$port" "$AMQPURL" "$size" "$seed" "$network" | tee runner_log
 \"\"\"
 if ${gdrive_enable}:
     entry_str += r\"\"\"PS4='Line ${LINENO}: ' bash -x gdrive_setup >>loggdrive &\"\"\"
@@ -501,31 +510,7 @@ while True:
 # https://stackoverflow.com/questions/31833897/python-read-from-subprocess-stdout-and-stderr-separately-while-pr
 # eserving-order
 # Title: Python read from subprocess stdout and stderr separately while preserving order - Stack Overflow
-#
-# Size: 110088
-# Codepage: Unicode UTF-8
-# SSL Cipher: 128-bit TLSv1.2 ECDHE-RSA-AES128-GCM-SHA256
-# Encoding: gzip
-# Date: Mon, 04 May 2020 23:38:11 GMT
-# Last modified: Mon, 04 May 2020 23:38:11 GMT
-# Time since loading: 13:08
-# Last visit time: Tue May  5 07:41:07 2020
-#
-# Link: https://stackoverflow.com/a/56918582
-# Link title: short permalink to this answer
-
-# just a test problem
-# import sys
-# from time import sleep
-#
-# for i in range(10):
-#     print(f" x{i} ", file=sys.stderr, end="")
-#     sleep(0.1)
-#     print(f" y{i} ", end="")
-#     sleep(0.1)
-# %%
-# #%run /opt/conda/bin/pytest --pdb -s -k "test_pytorch"
-    """
+"""
         )
 
         try:
@@ -592,7 +577,7 @@ if __name__ == "__main__":
     port = sys.argv[1]
     assert int(port) >= 0
     phase = sys.argv[2]
-    logger.debug(f"{sys.argv}")
+    logger.debug(f"Paramters for creating runner: {sys.argv}")
     tmp_path = '.r'
 
     subprocess.run(f"rm -rf {tmp_path}", shell=True, check=True)
